@@ -1062,21 +1062,29 @@ proc member { list item } {
 # openurl
 doc add "Procedures ($doc_type)/$doc_section/openurl" "openurl <pathname>
 
-Gets the text from the URL tag currently in focus from pathname, then runs netscape -remote, or just runs netscape if netscape isn't running."
+Gets the text from the URL tag currently in focus from pathname, then runs netscape -remote, or just runs netscape if netscape isn't running.  If url_command is not set to builtin_netscape, whatever is in the url_command variable is run."
 
 proc openurl { pathname } {
     set text [$pathname tag prevrange URL [$pathname index insert]]
     set list1 [split $text]
     set temps [$pathname get [lindex $list1 0] [lindex $list1 1]]
-    if { [is_link $::env(HOME)/.netscape/lock] } {
-	if { [catch {
-	    exec netscape -remote openURL($temps,new-window) 2>&1 > /dev/null &
-	}] } {
-	    file delete $::env(HOME)/.netscape/lock
+    if { $::dynamic::url_command == "builtin_netscape" } {
+	if { [is_link $::env(HOME)/.netscape/lock] } {
+	    if { [catch {
+		exec netscape -remote openURL($temps,new-window) 2>&1 > /dev/null &
+	    }] } {
+		file delete $::env(HOME)/.netscape/lock
+		exec netscape $temps 2>&1 > /dev/null &
+	    }
+	} else {
 	    exec netscape $temps 2>&1 > /dev/null &
 	}
     } else {
-	exec netscape $temps 2>&1 > /dev/null &
+	set command [escape $::dynamic::url_command]
+        regsub -all -- {\\ } $command { } command2
+        regsub -all -- {\\"} $command2 {"} command
+        set command [parseformat $command {{u {[escape $temps]}}}]
+        eval "exec $command"
     }
 }
     
@@ -1509,6 +1517,7 @@ set command_storage ""
 #-  Which key is it? (Ability to press key)
 #-  What code should be run (multiple choice as well as custom)
 #-Support for mice somehow?
+
 bind . <Up> {histup}
 bind . <Down> {histdown}
 bind . <Control-p> {histup}
@@ -1549,6 +1558,44 @@ bind . <Control-t> {
 }
 bind . <F1> {doc show}
 
+# For MouseWheel: 4 is up, 5 is down.
+# %b is button number
+# %X is root x coord
+# %Y is root y coord
+# winfo contains <x> <y> returns pathname
+
+bind . <ButtonPress> {mousewheel "" %b %X %Y}
+bind . <Shift-ButtonPress> {mousewheel "shift" %b %X %Y}
+bind . <Control-ButtonPress> {mousewheel "control" %b %X %Y}
+
+proc mousewheel {mod button x y} {
+    if { $button == 4 } {
+        set direction -1
+    } elseif { $button == 5 } {
+        set direction 1
+    } else {
+        return
+    }
+    if { $mod == "" } {
+        set direction [expr $direction*5]
+    }
+    set type "units"
+    if { $mod == "control" } {
+        set type "pages"
+    }
+    set pathname [winfo containing $x $y]
+    if { $pathname == ".windowlist.t" ||
+         [string match "*.nicks" $pathname] ||
+         [string match "*.text" $pathname] ||
+         [string match "*.list" $pathname] } {
+        $pathname yview scroll $direction $type
+    }
+    if { [string match "*.entry" $pathname] } {
+        if {$direction < 0} { histup }
+        if {$direction > 0} { histdown }
+    }
+}
+    
 # Make AppIcons work... maybe not.
 #wm command . quirc
 #wm group . .
