@@ -173,6 +173,9 @@ config type timestamp boolean
 doc add "Variables (Config)/Internal/timestamp_format" "The format to use for the timestamp.  For available formats, see the documentation for the clock format tcl command."
 config default timestamp_format [set ::dynamic::timestamp_format "\[%m/%d %H:%M:%S]"]
 
+doc add "Variables (Config)/Internal/url_command" "This is used to configure the command used when urls are clicked on.  If you want the built in intelligent netscape handler, use builtin_netscape as the command.  Otherwise, write your command with %u wherever you want the url to appear."
+config default url_command [set ::dynamic::url_command "builtin_netscape"]
+
 doc add "Variables (Config)/Internal/url_highlighting" "This setting is used to control whether or not urls will be highlighted and clickable."
 config default url_highlighting [set ::dynamic::url_highlighting 1]
 config type url_highlighting boolean
